package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TbXnszzMemberMapper;
import com.ruoyi.system.domain.TbXnszzMember;
import com.ruoyi.system.service.ITbXnszzMemberService;

/**
 * 小牛用户表Service业务层处理
 * 
 * @author Ashe
 * @date 2025-11-14
 */
@Service
public class TbXnszzMemberServiceImpl implements ITbXnszzMemberService 
{
    @Autowired
    private TbXnszzMemberMapper tbXnszzMemberMapper;

    /**
     * 查询小牛用户表
     * 
     * @param id 小牛用户表主键
     * @return 小牛用户表
     */
    @Override
    public TbXnszzMember selectTbXnszzMemberById(Long id)
    {
        return tbXnszzMemberMapper.selectTbXnszzMemberById(id);
    }

    /**
     * 查询小牛用户表列表
     * 
     * @param tbXnszzMember 小牛用户表
     * @return 小牛用户表
     */
    @Override
    public List<TbXnszzMember> selectTbXnszzMemberList(TbXnszzMember tbXnszzMember)
    {
        return tbXnszzMemberMapper.selectTbXnszzMemberList(tbXnszzMember);
    }

    /**
     * 新增小牛用户表
     * 
     * @param tbXnszzMember 小牛用户表
     * @return 结果
     */
    @Override
    public int insertTbXnszzMember(TbXnszzMember tbXnszzMember)
    {
        return tbXnszzMemberMapper.insertTbXnszzMember(tbXnszzMember);
    }

    /**
     * 修改小牛用户表
     * 
     * @param tbXnszzMember 小牛用户表
     * @return 结果
     */
    @Override
    public int updateTbXnszzMember(TbXnszzMember tbXnszzMember)
    {
        return tbXnszzMemberMapper.updateTbXnszzMember(tbXnszzMember);
    }

    /**
     * 批量删除小牛用户表
     * 
     * @param ids 需要删除的小牛用户表主键
     * @return 结果
     */
    @Override
    public int deleteTbXnszzMemberByIds(Long[] ids)
    {
        return tbXnszzMemberMapper.deleteTbXnszzMemberByIds(ids);
    }

    /**
     * 删除小牛用户表信息
     * 
     * @param id 小牛用户表主键
     * @return 结果
     */
    @Override
    public int deleteTbXnszzMemberById(Long id)
    {
        return tbXnszzMemberMapper.deleteTbXnszzMemberById(id);
    }
}
